@@ -21,7 +21,7 @@ files = {self.conf_dir}/*.ini
             f.write(data)
 
     def start(self):
-        run_shell(f"supervisord -c {self.manage_conf_path}")
+        run_shell(f"supervisorctl -c {self.manage_conf_path}")
 
     def add_job(self, server_name, directory, command, user='bingtao', stdout_logfile=None):
         default_logfile = f'/notechats/logs/notebuild/{server_name}.log'
